@@ -18,7 +18,6 @@ import importlib
 import inspect
 import platform
 import sys
-import time
 import typing
 
 PYPY = platform.python_implementation() == "PyPy"
@@ -50,10 +49,6 @@ def int_to_byte(i):
     return bytes([i])
 
 
-def benchmark_time():
-    return time.monotonic()
-
-
 def a_good_encoding():
     return "utf-8"
 
@@ -222,21 +217,12 @@ def ceil(x):
     return y
 
 
-try:
-    from django.test import TransactionTestCase
-
-    def bad_django_TestCase(runner):
-        if runner is None:
-            return False
-        if not isinstance(runner, TransactionTestCase):
-            return False
-
-        from hypothesis.extra.django._impl import HypothesisTestCase
-
-        return not isinstance(runner, HypothesisTestCase)
-
-
-except Exception:
-    # Can't use ImportError, because of e.g. Django config errors
-    def bad_django_TestCase(runner):
+def bad_django_TestCase(runner):
+    if runner is None or "django.test" not in sys.modules:
         return False
+    if not isinstance(runner, sys.modules["django.test"].TransactionTestCase):
+        return False
+
+    from hypothesis.extra.django._impl import HypothesisTestCase
+
+    return not isinstance(runner, HypothesisTestCase)
