@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,20 +13,17 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import enum
 import hashlib
 import heapq
-from collections import OrderedDict
+import sys
+from collections import OrderedDict, abc
 from fractions import Fraction
 
 from hypothesis.errors import InvalidArgument
 from hypothesis.internal.compat import (
-    abc,
     bit_length,
     floor,
-    hrange,
     int_from_bytes,
     qualname,
     str_to_bytes,
@@ -64,7 +59,7 @@ ONE_FROM_MANY_LABEL = calc_label_from_name("one more from many()")
 def integer_range(data, lower, upper, center=None):
     assert lower <= upper
     if lower == upper:
-        # Write a value even when this is trival so that when a bound depends
+        # Write a value even when this is trivial so that when a bound depends
         # on other values we don't suddenly disappear when the gap shrinks to
         # zero - if that happens then often the data stream becomes misaligned
         # and we fail to shrink in cases where we really should be able to.
@@ -114,14 +109,8 @@ def integer_range(data, lower, upper, center=None):
     return int(result)
 
 
-try:
-    from numpy import ndarray
-except ImportError:  # pragma: no cover
-    ndarray = ()
-
-
 def check_sample(values, strategy_name):
-    if isinstance(values, ndarray):
+    if "numpy" in sys.modules and isinstance(values, sys.modules["numpy"].ndarray):
         if values.ndim != 1:
             raise InvalidArgument(
                 (
@@ -250,7 +239,7 @@ def biased_coin(data, p):
     return result
 
 
-class Sampler(object):
+class Sampler:
     """Sampler based on Vose's algorithm for the alias method. See
     http://www.keithschwarz.com/darts-dice-coins/ for a good explanation.
 
@@ -272,7 +261,7 @@ class Sampler(object):
 
         n = len(weights)
 
-        self.table = [[i, None, None] for i in hrange(n)]
+        self.table = [[i, None, None] for i in range(n)]
 
         total = sum(weights)
 
@@ -344,7 +333,7 @@ class Sampler(object):
             return base
 
 
-class many(object):
+class many:
     """Utility class for collections. Bundles up the logic we use for "should I
     keep drawing more values?" and handles starting and stopping examples in
     the right place.
@@ -405,7 +394,9 @@ class many(object):
         self.count -= 1
         self.rejections += 1
         self.rejected = True
-        if self.rejections > 2 * self.count:
+        # We set a minimum number of rejections before we give up to avoid
+        # failing too fast when we reject the first draw.
+        if self.rejections > max(3, 2 * self.count):
             if self.count < self.min_size:
                 self.data.mark_invalid()
             else:
