@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,14 +13,11 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import decimal
 import math
 from numbers import Rational, Real
 
 from hypothesis.errors import InvalidArgument
-from hypothesis.internal.compat import integer_types
 from hypothesis.internal.coverage import check_function
 
 
@@ -31,10 +26,11 @@ def check_type(typ, arg, name=""):
     if name:
         name += "="
     if not isinstance(arg, typ):
-        if isinstance(typ, type):
-            typ_string = typ.__name__
-        else:
+        if isinstance(typ, tuple):
+            assert len(typ) >= 2, "Use bare type instead of len-1 tuple"
             typ_string = "one of %s" % (", ".join(t.__name__ for t in typ))
+        else:
+            typ_string = typ.__name__
         raise InvalidArgument(
             "Expected %s but got %s%r (type=%s)"
             % (typ_string, name, arg, type(arg).__name__)
@@ -49,7 +45,7 @@ def check_valid_integer(value):
     """
     if value is None:
         return
-    check_type(integer_types, value)
+    check_type(int, value)
 
 
 @check_function
@@ -58,12 +54,12 @@ def check_valid_bound(value, name):
 
     Otherwise raises InvalidArgument.
     """
-    if value is None or isinstance(value, integer_types + (Rational,)):
+    if value is None or isinstance(value, (int, Rational)):
         return
     if not isinstance(value, (Real, decimal.Decimal)):
         raise InvalidArgument("%s=%r must be a real number." % (name, value))
     if math.isnan(value):
-        raise InvalidArgument(u"Invalid end point %s=%r" % (name, value))
+        raise InvalidArgument("Invalid end point %s=%r" % (name, value))
 
 
 @check_function
@@ -86,47 +82,25 @@ def try_convert(typ, value, name):
         return value
     try:
         return typ(value)
-    except TypeError:
+    except (TypeError, ValueError, ArithmeticError):
         raise InvalidArgument(
             "Cannot convert %s=%r of type %s to type %s"
             % (name, value, type(value).__name__, typ.__name__)
         )
-    except (OverflowError, ValueError, ArithmeticError):
-        raise InvalidArgument(
-            "Cannot convert %s=%r to type %s" % (name, value, typ.__name__)
-        )
 
 
 @check_function
 def check_valid_size(value, name):
     """Checks that value is either unspecified, or a valid non-negative size
-    expressed as an integer/float.
+    expressed as an integer.
 
     Otherwise raises InvalidArgument.
     """
-    if value is None:
-        if name == "min_size":
-            from hypothesis._settings import note_deprecation
-
-            note_deprecation(
-                "min_size=None is deprecated; use min_size=0 instead.",
-                since="2018-10-06",
-            )
+    if value is None and name != "min_size":
         return
-    if isinstance(value, float):
-        if math.isnan(value):
-            raise InvalidArgument(u"Invalid size %s=%r" % (name, value))
-        from hypothesis._settings import note_deprecation
-
-        note_deprecation(
-            "Float size are deprecated: "
-            "%s should be an integer, got %r" % (name, value),
-            since="2018-10-11",
-        )
-    else:
-        check_type(integer_types, value)
+    check_type(int, value, name)
     if value < 0:
-        raise InvalidArgument(u"Invalid size %s=%r < 0" % (name, value))
+        raise InvalidArgument("Invalid size %s=%r < 0" % (name, value))
 
 
 @check_function
